==> xl-react-components-0.16.62.tgz: package/app/xl-react-widget/xl-react-widget-date/xl-react-widget-date-component.js <==
import moment from 'moment';
import PropTypes from 'prop-types';
import React, {Component} from 'react';
import 'react-datepicker/dist/react-datepicker.css';
import DatePicker from 'react-datepicker';
import {xlMessageTypeProp} from '../../xl-props/xl-message-type-prop';
import {validationMessageClasses} from '../../utils/css-utils';
import {XlReactFormItemControl} from '../../xl-react-form/xl-react-form-item-control';
import './xl-react-widget-date.less';

export class XlReactWidgetDateComponent extends Component {
    static propTypes = {
        assignRef: PropTypes.func,
        dateFormat: PropTypes.string,
        description: PropTypes.string,
        disabled: PropTypes.bool,
        displayMode: PropTypes.string,
        handleModelChange: PropTypes.func,
        handleOnBlur: PropTypes.func,
        label: PropTypes.string,
        maxDate: PropTypes.object,
        message: xlMessageTypeProp,
        minDate: PropTypes.object,
        model: PropTypes.object,
        placeholderText: PropTypes.string,
        valid: PropTypes.bool
    };

    constructor(props) {
        super(props);
        this.state = {};
    }

    componentWillMount() {
        this.updateStateIfDateIsValid(this.props);
    }

    componentWillReceiveProps(nextProps) {
        this.updateStateIfDateIsValid(nextProps);
    }

    handleChangeRaw = (event) => {
        event.preventDefault();
        this.setState({value: event.target.value});
    };

    updateStateIfDateIsValid = ({model, dateFormat}) => {
        if (moment(model, dateFormat, true).isValid()) {
            this.setState({value: moment(model).format(dateFormat)});
        }
    };

    render() {
        const {
            assignRef, dateFormat, disabled,
            handleOnBlur: onBlur,
            handleModelChange: onChange,
            maxDate, message, minDate, placeholderText, model, valid
        } = this.props;
        const {value} = this.state;

        const getModel = () => moment(model).isValid() ? moment(model).toDate() : null;

        const customControlClasses = validationMessageClasses(valid, message);
        const itemProps = {...this.props, controlClass: 'xl-react-widget-date', customControlClasses};

        return <XlReactFormItemControl {...itemProps}>
            <i className="glyphicon glyphicon-calendar"/>
            <DatePicker
                ref={assignRef}
                {...({
                    dateFormat,
                    disabled,
                    maxDate,
                    minDate,
                    onBlur,
                    onChange,
                    onChangeRaw: this.handleChangeRaw,
                    placeholderText,
                    selected: getModel(),
                    value
                })}
            />
        </XlReactFormItemControl>;
    }
}

==> xl-react-components-0.18.103.tgz: package/app/xl-react-widget/xl-react-widget-date/xl-react-widget-date-component.js <==
import moment from 'moment';
import PropTypes from 'prop-types';
import React, {Component} from 'react';
import 'react-datepicker/dist/react-datepicker.css';
import DatePicker from 'react-datepicker';
import {xlMessageTypeProp} from '../../xl-props/xl-message-type-prop';
import {validationMessageClasses} from '../../utils/css-utils';
import {XlReactFormItemControl} from '../../xl-react-form/xl-react-form-item-control';
import './xl-react-widget-date.less';

export class XlReactWidgetDateComponent extends Component {
    static propTypes = {
        assignRef: PropTypes.func,
        className: PropTypes.string,
        dateFormat: PropTypes.string,
        description: PropTypes.string,
        disabled: PropTypes.bool,
        displayMode: PropTypes.string,
        handleModelChange: PropTypes.func,
        handleOnBlur: PropTypes.func,
        label: PropTypes.string,
        maxDate: PropTypes.object,
        message: xlMessageTypeProp,
        minDate: PropTypes.object,
        model: PropTypes.object,
        placeholderText: PropTypes.string,
        valid: PropTypes.bool
    };

    constructor(props) {
        super(props);
        this.state = {};
    }

    componentWillMount() {
        this.updateStateIfDateIsValid(this.props);
    }

    componentWillReceiveProps(nextProps) {
        this.updateStateIfDateIsValid(nextProps);
    }

    handleChangeRaw = (event) => {
        event.preventDefault();
        this.setState({value: event.target.value});
    };

    updateStateIfDateIsValid = ({model, dateFormat}) => {
        if (moment(model, dateFormat, true).isValid()) {
            this.setState({value: moment(model).format(dateFormat)});
        }
    };

    render() {
        const {
            assignRef, className, dateFormat, disabled,
            handleOnBlur: onBlur,
            handleModelChange: onChange,
            maxDate, message, minDate, placeholderText, model, valid
        } = this.props;
        const {value} = this.state;

        const getModel = () => moment(model).isValid() ? moment(model).toDate() : null;

        const customControlClasses = validationMessageClasses(valid, message);
        const itemProps = {...this.props, controlClass: 'xl-react-widget-date', customControlClasses};

        return <XlReactFormItemControl {...itemProps}>
            <i className="glyphicon glyphicon-calendar"/>
            <DatePicker
                ref={assignRef}
                {...({
                    className,
                    dateFormat,
                    disabled,
                    maxDate,
                    minDate,
                    onBlur,
                    onChange,
                    onChangeRaw: this.handleChangeRaw,
                    placeholderText,
                    selected: getModel(),
                    value
                })}
            />
        </XlReactFormItemControl>;
    }
}
